@@ -5,9 +5,13 @@ require 'yaml'
 require 'tempfile'
 
 module Session 
-  VERSION = '3.1.0'
+  VERSION = '3.2.0'
   def self.version() VERSION end
 
+  def Session.description
+    'persistent connections with external programs like bash'
+  end
+
   @track_history = ENV['SESSION_HISTORY'] || ENV['SESSION_TRACK_HISTORY']
   @use_spawn     = ENV['SESSION_USE_SPAWN']
   @use_open3     = ENV['SESSION_USE_OPEN3']
@@ -373,6 +377,9 @@ module Session
 
                 line = iodat[:io].gets
 
+                # In case their are weird chars, this will avoid a "invalid byte sequence in US-ASCII" error
+                line.force_encoding("binary") if line.respond_to? :force_encoding
+
                 buf = nil
 
                 case line
